export declare namespace Five9Types {
    enum MessageType {
        TEXT = "TEXT"
    }
    enum AcknowledgeType {
        DELIVERED = "DELIVERED",
        READ = "READ",
        FAILED = "FAILED"
    }
    enum ContentType {
        GENERIC = "GENERIC",
        SMS = "SMS",
        RCS = "RCS",
        FACEBOOK = "FACEBOOK",
        TWITTER = "TWITTER",
        WHATSAPP = "WHATSAPP",
        WECHAT = "WECHAT",
        QQMOBILE = "QQMOBILE",
        APPLE_BUSINESS_CHAT = "APPLE_BUSINESS_CHAT",
        SKYPE = "SKYPE",
        SNAPCHAT = "SNAPCHAT",
        VIBER = "VIBER",
        LINE = "LINE",
        TELEGRAM = "TELEGRAM",
        KAKAO = "KAKAO"
    }
    enum ConversationEventOrigin {
        SYSTEM = "SYSTEM",
        USER = "USER"
    }
    enum ConversationStatus {
        PENDING = "PENDING",
        ACTIVE = "ACTIVE",
        TERMINATED = "TERMINATED"
    }
    type AcknowledgeMessage = {
        type: AcknowledgeType;
        messageId: string;
    };
    type AcknowledgeMessages = {
        messages: AcknowledgeMessage[];
    };
    type AnonymousUser = {
        tenantName: string;
    };
    type Contact = {
        email?: string;
        firstName?: string;
        lastName?: string;
        company?: string;
        street?: string;
        city?: string;
        state?: string;
        zip?: string;
        gender?: string;
        number1?: string;
        number2?: string;
        number3?: string;
        socialAccountHandle?: string;
        socialAccountName?: string;
        socialAccountImageUrl?: string;
        socialAccountProfileUrl?: string;
    };
    type Conversation = {
        type: ContentType;
        tenantId: number;
        callbackUrl: string;
        campaignName?: string;
        campaignId?: number;
        contact: Contact;
        attributes?: Record<string, string>;
        disableAutoClose?: boolean;
        disableComfortMessage?: boolean;
        useBusinessHours?: boolean;
        externalId?: string;
        priority?: number;
    };
    type ConversationAcceptEvent = {
        correlationId: string;
        displayName: string;
        externalId?: string;
        eventSerialNumber: number;
        from: ConversationBind;
        timestamp: string;
        userId: number;
    };
    type ConversationBind = any;
    type ConversationErrorEvent = {
        correlationId: string;
        contentType: ContentType;
        displayName: string;
        externalId?: string;
        eventSerialNumber: number;
        from: ConversationBind[];
        messageId: string;
        messageSerialNumber: number;
        messageType: number;
        text: string;
        timestamp: string;
        userId: number;
    };
    type ConversationEvent = {
        correlationId: string;
        externalId?: string;
        timestamp: string;
        eventSerialNumber: number;
    };
    type ConversationInfo = {
        id: string;
        status: ConversationTypingEvent;
        disposition: number;
    };
    type ConversationMessageEvent = {
        contentType: ContentType;
        correlationId: string;
        displayName: string;
        eventSerialNumber: number;
        externalId?: string;
        from: string;
        messageId: string;
        text: string;
        timestamp: string;
        userId: number;
        attachments: string[];
    };
    type ConversationParticipantEvent = {
        correlationId: string;
        displayName: string;
        eventSerialNumber: number;
        externalId?: string;
        participants: Metadata[];
        timestamp: string;
        userId: number;
    };
    type ConversationTerminateEvent = {
        correlationId: string;
        displayName: string;
        externalId?: string;
        eventSerialNumber: number;
        from: ConversationBind;
        timestamp: string;
        userId: number;
    };
    type ConversationTransferEvent = {
        correlationId: string;
        externalId?: string;
        eventSerialNumber: number;
        fromDisplayName: string;
        fromUserId: number;
        timestamp: string;
    };
    type ConversationTransferToAgentEvent = {
        correlationId: string;
        externalId?: string;
        eventSerialNumber: number;
        fromDisplayName: string;
        fromUserId: number;
        toDisplayName: string;
        toUserId: number;
        participants: Metadata[];
        timestamp: string;
    };
    type ConversationTransferToGroupEvent = {
        correlationId: string;
        externalId?: string;
        eventSerialNumber: number;
        fromDisplayName: string;
        fromUserId: number;
        groupId: number;
        groupName: string;
        timestamp: string;
    };
    type ConversationTypingEvent = {
        correlationId: string;
        displayName: string;
        externalId?: string;
        eventSerialNumber: number;
        timestamp: string;
        userId: number;
    };
    type Generic500ErrorResponse = {
        description: string;
    };
    type Group = {
        groupId: number;
        groupName: string;
    };
    type Message = {
        messageType: MessageType;
        message: string;
        externalId?: string;
        attachments?: string[];
    };
    type Participant = {
        userId: number;
        displayName: string;
    };
    type Five9Config = {
        tenantName: string;
        campaignName: string;
        callbackUrl: string;
    };
    type ApiUrl = {
        host: string;
        port: string;
        routeKey: string;
        version: string;
    };
    type DataCenter = {
        name: string;
        uiUrls: ApiUrl[];
        apiUrls: ApiUrl[];
        loginUrls: ApiUrl[];
        active: boolean;
    };
    type Metadata = {
        freedomUrl: string;
        dataCenters: DataCenter[];
    };
    type SessionToken = {
        context: Map<string, string> & {
            farmId: string;
        };
        metadata: Metadata;
        orgId: string;
        tokenId: string;
        userId: string;
    };
}
